@@ -54,8 +54,8 @@ def add_mimedb_data(mimedb: mimetypes.MimeTypes) -> None:
     add_mimetype(mimedb, 'application/x-lzma', '.lzma')
     add_mimetype(mimedb, 'application/x-xz', '.xz')
     add_mimetype(mimedb, 'application/java-archive', '.jar')
-    add_mimetype(mimedb, 'application/x-rar', '.rar')
-    add_mimetype(mimedb, 'application/x-rar', '.cbr')
+    add_mimetype(mimedb, 'application/vnd.rar', '.rar')
+    add_mimetype(mimedb, 'application/vnd.rar', '.cbr')
     add_mimetype(mimedb, 'application/x-7z-compressed', '.7z')
     add_mimetype(mimedb, 'application/x-7z-compressed', '.cb7')
     add_mimetype(mimedb, 'application/x-cab', '.cab')
@@ -135,8 +135,13 @@ Encoding2Mime: dict[str, str] = {
 Mime2Encoding: dict[str, str] = dict(
     [(_val, _key) for _key, _val in Encoding2Mime.items()]
 )
-# libmagic before version 5.14 identified .gz files as application/x-gzip
-Mime2Encoding['application/x-gzip'] = 'gzip'
+
+LegacyMimeType: dict[str, str] = {
+    # libmagic before version 5.14 identified .gz files as application/x-gzip
+    'application/x-gzip': "application/gzip",
+    # libmagic before version 5.46 identified .rar files as application/x-rar
+    'application/x-rar': "application/vnd.rar",
+}
 
 
 def guess_mime_mimedb(filename: str) -> tuple[str | None, str | None]:
@@ -168,10 +173,6 @@ def guess_mime_file(filename: str) -> tuple[str | None, str | None]:
     @return: tuple (mime, encoding)
     """
     mime, encoding = None, None
-    base, ext = os.path.splitext(filename)
-    if ext.lower() in ('.alz',):
-        # let mimedb recognize these extensions
-        return mime, encoding
     if os.path.isfile(filename):
         file_prog = find_program("file")
         if file_prog:
@@ -192,6 +193,10 @@ def guess_mime_file(filename: str) -> tuple[str | None, str | None]:
         except (OSError, subprocess.CalledProcessError) as err:
             log_warning(f"error executing {cmd}: {err}")
             mime2 = None
+
+        if mime2 in LegacyMimeType:
+            mime2 = LegacyMimeType[mime2]
+
         # Some file(1) implementations return an empty or unknown mime type
         # when the uncompressor program is not installed, other
         # implementation return the original file type.
@@ -227,6 +232,10 @@ def guess_mime_file_mime(
     except OSError as err:
         # ignore errors, as file(1) is only a fallback
         log_warning(f"error executing {cmd}: {err}")
+
+    if mime in LegacyMimeType:
+        mime = LegacyMimeType[mime]
+
     if mime not in ArchiveMimetypes:
         mime, encoding = None, None
     return mime, encoding
@@ -246,6 +255,7 @@ def get_file_mime_encoding(parts: Sequence[str]) -> str | None:
 FileText2Mime: dict[str, str] = {
     "7-zip archive data": "application/x-7z-compressed",
     "ACE archive data": "application/x-ace",
+    "ALZ archive data": "application/x-alzip",
     "Amiga DOS disk": "application/x-adf",
     "ARJ archive data": "application/x-arj",
     "bzip2 compressed data": "application/x-bzip2",
@@ -253,13 +263,13 @@ FileText2Mime: dict[str, str] = {
     "cpio archive": "application/x-cpio",
     "ASCII cpio archive": "application/x-cpio",
     "Debian binary package": "application/x-debian-package",
-    "gzip compressed data": "application/x-gzip",
+    "gzip compressed data": "application/gzip",
     "LZMA compressed data": "application/x-lzma",
     "LRZIP compressed data": "application/x-lrzip",
     "lzop compressed data": "application/x-lzop",
     "Microsoft Cabinet archive data": "application/vnd.ms-cab-compressed",
-    "RAR archive data": "application/x-rar",
-    "RPM ": "application/x-redhat-package-manager",
+    "RAR archive data": "application/vnd.rar",
+    "RPM ": "application/x-rpm",
     "POSIX tar archive": "application/x-tar",
     "xz compressed data": "application/x-xz",
     "Zip archive data": "application/zip",
