@@ -16,6 +16,7 @@
 
 import functools
 import os
+import re
 import sys
 import shutil
 import subprocess
@@ -111,26 +112,36 @@ def shell_quote_nt(value: str) -> str:
     return value
 
 
-def p7zip_supports_rar() -> bool:
-    """Determine if the RAR codec is installed for 7z program."""
-    if os.name == 'nt':
-        # Assume RAR support is compiled into the binary.
-        return True
-    # the subdirectory and codec name
-    codecnames = ['p7zip/Codecs/Rar29.so', 'p7zip/Codecs/Rar.so']
-    # search canonical user library dirs
-    for libdir in (
-        '/usr/lib',
-        '/usr/local/lib',
-        '/usr/lib64',
-        '/usr/local/lib64',
-        '/usr/lib/i386-linux-gnu',
-        '/usr/lib/x86_64-linux-gnu',
-    ):
-        for codecname in codecnames:
-            fname = os.path.join(libdir, codecname)
-            if os.path.exists(fname):
-                return True
+def p7zip_supports_rar(program: str) -> bool:
+    """Determine if the RAR codec is installed for 7z program.
+    If installed, `7z i` will print something like
+    ...
+    Codecs:
+    1   D    40301 Rar1
+    1   D    40302 Rar2
+    1   D    40303 Rar3
+    1   D    40305 Rar5
+    ...
+    """
+    _7z = find_program(program)
+    if _7z:
+        formats = backtick([_7z, "i"])
+        return bool(re.search(r" Rar\d$", formats, re.MULTILINE))
+    return False
+
+
+def p7zip_supports_compress(program: str) -> bool:
+    """Determine if COMPRESS (.Z) archives are supported for 7z program.
+    If installed, `7z i` will print something like
+    ...
+    Formats:
+    0  ......................  Z        z taz (.tar)  1F 9D
+    ...
+    """
+    _7z = find_program(program)
+    if _7z:
+        formats = backtick([_7z, "i"])
+        return bool(re.search(r"Z\s+z\s+taz", formats, re.MULTILINE))
     return False
 
 
