@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,15 +12,20 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the flac program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestFlac (ArchiveTest):
+
+class TestFlac(ArchiveTest):
+    """Test class for the flac program"""
 
     program = 'flac'
 
     @needs_program(program)
     def test_flac(self):
+        """Extract, test and create a FLAC archive."""
         self.archive_extract('t.flac', check=None)
         self.archive_test('t.flac')
         self.archive_create('t.flac', srcfiles=("t.wav",))
@@ -29,5 +33,6 @@ class TestFlac (ArchiveTest):
     @needs_program('file')
     @needs_program(program)
     def test_flac_file(self):
+        """Extract and test a renamed FLAC archive."""
         self.archive_extract('t.flac.foo', check=None)
         self.archive_test('t.flac.foo')
