@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2013-2015 Bastian Kleineidam
+# Copyright (C) 2013-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,6 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test patool extract command."""
+
 import unittest
 import os
 from patoolib import fileutil, cli
@@ -20,9 +21,11 @@ from . import basedir, datadir, needs_program
 
 
 class ArchiveExtractTest(unittest.TestCase):
+    """Test class for patool extract command."""
 
     @needs_program('7z')
     def test_extract(self):
+        """Run cli function to extract a 7Z archive."""
         tmpdir = fileutil.tmpdir(dir=basedir)
         try:
             archive = os.path.join(datadir, "t .7z")
